@@ -4,7 +4,7 @@
 
 /* #include <libtasn1.h> */
 
-const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
+const asn1_static_node pkix_asn1_tab[] = {
   { "PKIX1", 536875024, NULL },
   { NULL, 1073741836, NULL },
   { "id-ce", 1879048204, NULL },
@@ -43,9 +43,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "16"},
   { "PrivateKeyUsagePeriod", 1610612741, NULL },
-  { "notBefore", 1619025937, NULL },
+  { "notBefore", 1610637349, NULL },
   { NULL, 4104, "0"},
-  { "notAfter", 545284113, NULL },
+  { "notAfter", 536895525, NULL },
   { NULL, 4104, "1"},
   { "id-ce-certificatePolicies", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
@@ -64,7 +64,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "qualifier", 541065229, NULL },
   { "policyQualifierId", 1, NULL },
   { "PolicyQualifierId", 1073741836, NULL },
-  { "CPSuri", 1073741826, "IA5String"},
+  { "CPSuri", 1073741853, NULL },
   { "UserNotice", 1610612741, NULL },
   { "noticeRef", 1073758210, "NoticeReference"},
   { "explicitText", 16386, "DisplayText"},
@@ -73,11 +73,11 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "noticeNumbers", 536870923, NULL },
   { NULL, 3, NULL },
   { "DisplayText", 1610612754, NULL },
-  { "visibleString", 1612709890, "VisibleString"},
+  { "visibleString", 1612709923, NULL },
   { "200", 524298, "1"},
-  { "bmpString", 1612709890, "BMPString"},
+  { "bmpString", 1612709921, NULL },
   { "200", 524298, "1"},
-  { "utf8String", 538968066, "UTF8String"},
+  { "utf8String", 538968098, NULL },
   { "200", 524298, "1"},
   { "id-ce-policyMappings", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
@@ -88,17 +88,17 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "issuerDomainPolicy", 1073741826, "CertPolicyId"},
   { "subjectDomainPolicy", 2, "CertPolicyId"},
   { "DirectoryString", 1610612754, NULL },
-  { "teletexString", 1612709890, "TeletexString"},
+  { "teletexString", 1612709918, NULL },
   { "MAX", 524298, "1"},
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "MAX", 524298, "1"},
-  { "universalString", 1612709890, "UniversalString"},
+  { "universalString", 1612709920, NULL },
   { "MAX", 524298, "1"},
-  { "utf8String", 1612709890, "UTF8String"},
+  { "utf8String", 1612709922, NULL },
   { "MAX", 524298, "1"},
-  { "bmpString", 1612709890, "BMPString"},
+  { "bmpString", 1612709921, NULL },
   { "MAX", 524298, "1"},
-  { "ia5String", 538968066, "IA5String"},
+  { "ia5String", 538968093, NULL },
   { "MAX", 524298, "1"},
   { "id-ce-subjectAltName", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
@@ -110,9 +110,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "GeneralName", 1610612754, NULL },
   { "otherName", 1610620930, "AnotherName"},
   { NULL, 4104, "0"},
-  { "rfc822Name", 1610620930, "IA5String"},
+  { "rfc822Name", 1610620957, NULL },
   { NULL, 4104, "1"},
-  { "dNSName", 1610620930, "IA5String"},
+  { "dNSName", 1610620957, NULL },
   { NULL, 4104, "2"},
   { "x400Address", 1610620930, "ORAddress"},
   { NULL, 4104, "3"},
@@ -120,7 +120,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 2056, "4"},
   { "ediPartyName", 1610620930, "EDIPartyName"},
   { NULL, 4104, "5"},
-  { "uniformResourceIdentifier", 1610620930, "IA5String"},
+  { "uniformResourceIdentifier", 1610620957, NULL },
   { NULL, 4104, "6"},
   { "iPAddress", 1610620935, NULL },
   { NULL, 4104, "7"},
@@ -316,7 +316,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "id-ce-invalidityDate", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "24"},
-  { "InvalidityDate", 1082130449, NULL },
+  { "InvalidityDate", 1073741861, NULL },
   { "VisibleString", 1610620935, NULL },
   { NULL, 4360, "26"},
   { "NumericString", 1610620935, NULL },
@@ -430,24 +430,24 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "id-at-dnQualifier", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "46"},
-  { "X520dnQualifier", 1073741826, "PrintableString"},
+  { "X520dnQualifier", 1073741855, NULL },
   { "id-at-countryName", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "6"},
-  { "X520countryName", 1612709890, "PrintableString"},
+  { "X520countryName", 1612709919, NULL },
   { NULL, 1048586, "2"},
   { "id-at-serialNumber", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "5"},
-  { "X520serialNumber", 1073741826, "PrintableString"},
+  { "X520serialNumber", 1073741855, NULL },
   { "id-at-telephoneNumber", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "20"},
-  { "X520telephoneNumber", 1073741826, "PrintableString"},
+  { "X520telephoneNumber", 1073741855, NULL },
   { "id-at-facsimileTelephoneNumber", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "23"},
-  { "X520facsimileTelephoneNumber", 1073741826, "PrintableString"},
+  { "X520facsimileTelephoneNumber", 1073741855, NULL },
   { "id-at-pseudonym", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-at"},
   { NULL, 1, "65"},
@@ -478,7 +478,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "emailAddress", 1880096780, "AttributeType"},
   { NULL, 1073741825, "pkcs-9"},
   { NULL, 1, "1"},
-  { "Pkcs9email", 1612709890, "IA5String"},
+  { "Pkcs9email", 1612709917, NULL },
   { "ub-emailaddress-length", 524298, "1"},
   { "Name", 1610612754, NULL },
   { "rdnSequence", 2, "RDNSequence"},
@@ -517,8 +517,8 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "notBefore", 1073741826, "Time"},
   { "notAfter", 2, "Time"},
   { "Time", 1610612754, NULL },
-  { "utcTime", 1090519057, NULL },
-  { "generalTime", 8388625, NULL },
+  { "utcTime", 1073741860, NULL },
+  { "generalTime", 37, NULL },
   { "UniqueIdentifier", 1073741830, NULL },
   { "SubjectPublicKeyInfo", 1610612741, NULL },
   { "algorithm", 1073741826, "AlgorithmIdentifier"},
@@ -604,6 +604,175 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "p", 1073741827, NULL },
   { "q", 1073741827, NULL },
   { "g", 3, NULL },
+  { "ansi-X9-62", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { NULL, 1, "10045"},
+  { "id-ecSigType", 1879048204, NULL },
+  { NULL, 1073741825, "ansi-X9-62"},
+  { "signatures", 1, "4"},
+  { "ecdsa-with-SHA1", 1879048204, NULL },
+  { NULL, 1073741825, "id-ecSigType"},
+  { NULL, 1, "1"},
+  { "Ecdsa-Sig-Value", 1610612741, NULL },
+  { "r", 1073741827, NULL },
+  { "s", 3, NULL },
+  { "id-public-key-type", 1879048204, NULL },
+  { NULL, 1073741825, "ansi-X9-62"},
+  { NULL, 1, "2"},
+  { "id-ecPublicKey", 1879048204, NULL },
+  { NULL, 1073741825, "id-public-key-type"},
+  { NULL, 1, "1"},
+  { "ECPoint", 1073741831, NULL },
+  { "ECParameters", 1610612754, NULL },
+  { "namedCurve", 12, NULL },
+  { "secp192r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "curves", 1073741825, "3"},
+  { "prime", 1073741825, "1"},
+  { NULL, 1, "1"},
+  { "sect163k1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "1"},
+  { "sect163r2", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "15"},
+  { "secp224r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "33"},
+  { "sect233k1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "26"},
+  { "sect233r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "27"},
+  { "secp256r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "curves", 1073741825, "3"},
+  { "prime", 1073741825, "1"},
+  { NULL, 1, "7"},
+  { "sect283k1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "16"},
+  { "sect283r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "17"},
+  { "secp384r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "34"},
+  { "sect409k1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "36"},
+  { "sect409r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "37"},
+  { "secp521r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "35"},
+  { "sect571k1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "38"},
+  { "sect571r1", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "identified-organization", 1073741825, "3"},
+  { "certicom", 1073741825, "132"},
+  { "curve", 1073741825, "0"},
+  { NULL, 1, "39"},
+  { "id-dsa-with-sha224", 1879048204, NULL },
+  { "joint-iso-ccitt", 1073741825, "2"},
+  { "country", 1073741825, "16"},
+  { "us", 1073741825, "840"},
+  { "organization", 1073741825, "1"},
+  { "gov", 1073741825, "101"},
+  { "csor", 1073741825, "3"},
+  { "algorithms", 1073741825, "4"},
+  { "id-dsa-with-sha2", 1073741825, "3"},
+  { NULL, 1, "1"},
+  { "id-dsa-with-sha256", 1879048204, NULL },
+  { "joint-iso-ccitt", 1073741825, "2"},
+  { "country", 1073741825, "16"},
+  { "us", 1073741825, "840"},
+  { "organization", 1073741825, "1"},
+  { "gov", 1073741825, "101"},
+  { "csor", 1073741825, "3"},
+  { "algorithms", 1073741825, "4"},
+  { "id-dsa-with-sha2", 1073741825, "3"},
+  { NULL, 1, "2"},
+  { "ecdsa-with-SHA224", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "signatures", 1073741825, "4"},
+  { "ecdsa-with-SHA2", 1073741825, "3"},
+  { NULL, 1, "1"},
+  { "ecdsa-with-SHA256", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "signatures", 1073741825, "4"},
+  { "ecdsa-with-SHA2", 1073741825, "3"},
+  { NULL, 1, "2"},
+  { "ecdsa-with-SHA384", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "signatures", 1073741825, "4"},
+  { "ecdsa-with-SHA2", 1073741825, "3"},
+  { NULL, 1, "3"},
+  { "ecdsa-with-SHA512", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "us", 1073741825, "840"},
+  { "ansi-X9-62", 1073741825, "10045"},
+  { "signatures", 1073741825, "4"},
+  { "ecdsa-with-SHA2", 1073741825, "3"},
+  { NULL, 1, "4"},
   { "ORAddress", 1610612741, NULL },
   { "built-in-standard-attributes", 1073741826, "BuiltInStandardAttributes"},
   { "built-in-domain-defined-attributes", 1073758210, "BuiltInDomainDefinedAttributes"},
@@ -627,55 +796,55 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 2056, "6"},
   { "CountryName", 1610620946, NULL },
   { NULL, 1073746952, "1"},
-  { "x121-dcc-code", 1612709890, "NumericString"},
+  { "x121-dcc-code", 1612709916, NULL },
   { NULL, 1048586, "ub-country-name-numeric-length"},
-  { "iso-3166-alpha2-code", 538968066, "PrintableString"},
+  { "iso-3166-alpha2-code", 538968095, NULL },
   { NULL, 1048586, "ub-country-name-alpha-length"},
   { "AdministrationDomainName", 1610620946, NULL },
   { NULL, 1073744904, "2"},
-  { "numeric", 1612709890, "NumericString"},
+  { "numeric", 1612709916, NULL },
   { "ub-domain-name-length", 524298, "0"},
-  { "printable", 538968066, "PrintableString"},
+  { "printable", 538968095, NULL },
   { "ub-domain-name-length", 524298, "0"},
   { "NetworkAddress", 1073741826, "X121Address"},
-  { "X121Address", 1612709890, "NumericString"},
+  { "X121Address", 1612709916, NULL },
   { "ub-x121-address-length", 524298, "1"},
-  { "TerminalIdentifier", 1612709890, "PrintableString"},
+  { "TerminalIdentifier", 1612709919, NULL },
   { "ub-terminal-id-length", 524298, "1"},
   { "PrivateDomainName", 1610612754, NULL },
-  { "numeric", 1612709890, "NumericString"},
+  { "numeric", 1612709916, NULL },
   { "ub-domain-name-length", 524298, "1"},
-  { "printable", 538968066, "PrintableString"},
+  { "printable", 538968095, NULL },
   { "ub-domain-name-length", 524298, "1"},
-  { "OrganizationName", 1612709890, "PrintableString"},
+  { "OrganizationName", 1612709919, NULL },
   { "ub-organization-name-length", 524298, "1"},
-  { "NumericUserIdentifier", 1612709890, "NumericString"},
+  { "NumericUserIdentifier", 1612709916, NULL },
   { "ub-numeric-user-id-length", 524298, "1"},
   { "PersonalName", 1610612750, NULL },
-  { "surname", 1814044674, "PrintableString"},
+  { "surname", 1814044703, NULL },
   { NULL, 1073745928, "0"},
   { "ub-surname-length", 524298, "1"},
-  { "given-name", 1814061058, "PrintableString"},
+  { "given-name", 1814061087, NULL },
   { NULL, 1073745928, "1"},
   { "ub-given-name-length", 524298, "1"},
-  { "initials", 1814061058, "PrintableString"},
+  { "initials", 1814061087, NULL },
   { NULL, 1073745928, "2"},
   { "ub-initials-length", 524298, "1"},
-  { "generation-qualifier", 740319234, "PrintableString"},
+  { "generation-qualifier", 740319263, NULL },
   { NULL, 1073745928, "3"},
   { "ub-generation-qualifier-length", 524298, "1"},
   { "OrganizationalUnitNames", 1612709899, NULL },
   { "ub-organizational-units", 1074266122, "1"},
   { NULL, 2, "OrganizationalUnitName"},
-  { "OrganizationalUnitName", 1612709890, "PrintableString"},
+  { "OrganizationalUnitName", 1612709919, NULL },
   { "ub-organizational-unit-name-length", 524298, "1"},
   { "BuiltInDomainDefinedAttributes", 1612709899, NULL },
   { "ub-domain-defined-attributes", 1074266122, "1"},
   { NULL, 2, "BuiltInDomainDefinedAttribute"},
   { "BuiltInDomainDefinedAttribute", 1610612741, NULL },
-  { "type", 1612709890, "PrintableString"},
+  { "type", 1612709919, NULL },
   { "ub-domain-defined-attribute-type-length", 524298, "1"},
-  { "value", 538968066, "PrintableString"},
+  { "value", 538968095, NULL },
   { "ub-domain-defined-attribute-value-length", 524298, "1"},
   { "ExtensionAttributes", 1612709903, NULL },
   { "ub-extension-attributes", 1074266122, "1"},
@@ -688,48 +857,48 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073743880, "1"},
   { "extension-attribute-type", 1, NULL },
   { "common-name", 1342177283, "1"},
-  { "CommonName", 1612709890, "PrintableString"},
+  { "CommonName", 1612709919, NULL },
   { "ub-common-name-length", 524298, "1"},
   { "teletex-common-name", 1342177283, "2"},
-  { "TeletexCommonName", 1612709890, "TeletexString"},
+  { "TeletexCommonName", 1612709918, NULL },
   { "ub-common-name-length", 524298, "1"},
   { "teletex-organization-name", 1342177283, "3"},
-  { "TeletexOrganizationName", 1612709890, "TeletexString"},
+  { "TeletexOrganizationName", 1612709918, NULL },
   { "ub-organization-name-length", 524298, "1"},
   { "teletex-personal-name", 1342177283, "4"},
   { "TeletexPersonalName", 1610612750, NULL },
-  { "surname", 1814044674, "TeletexString"},
+  { "surname", 1814044702, NULL },
   { NULL, 1073743880, "0"},
   { "ub-surname-length", 524298, "1"},
-  { "given-name", 1814061058, "TeletexString"},
+  { "given-name", 1814061086, NULL },
   { NULL, 1073743880, "1"},
   { "ub-given-name-length", 524298, "1"},
-  { "initials", 1814061058, "TeletexString"},
+  { "initials", 1814061086, NULL },
   { NULL, 1073743880, "2"},
   { "ub-initials-length", 524298, "1"},
-  { "generation-qualifier", 740319234, "TeletexString"},
+  { "generation-qualifier", 740319262, NULL },
   { NULL, 1073743880, "3"},
   { "ub-generation-qualifier-length", 524298, "1"},
   { "teletex-organizational-unit-names", 1342177283, "5"},
   { "TeletexOrganizationalUnitNames", 1612709899, NULL },
   { "ub-organizational-units", 1074266122, "1"},
   { NULL, 2, "TeletexOrganizationalUnitName"},
-  { "TeletexOrganizationalUnitName", 1612709890, "TeletexString"},
+  { "TeletexOrganizationalUnitName", 1612709918, NULL },
   { "ub-organizational-unit-name-length", 524298, "1"},
   { "pds-name", 1342177283, "7"},
-  { "PDSName", 1612709890, "PrintableString"},
+  { "PDSName", 1612709919, NULL },
   { "ub-pds-name-length", 524298, "1"},
   { "physical-delivery-country-name", 1342177283, "8"},
   { "PhysicalDeliveryCountryName", 1610612754, NULL },
-  { "x121-dcc-code", 1612709890, "NumericString"},
+  { "x121-dcc-code", 1612709916, NULL },
   { NULL, 1048586, "ub-country-name-numeric-length"},
-  { "iso-3166-alpha2-code", 538968066, "PrintableString"},
+  { "iso-3166-alpha2-code", 538968095, NULL },
   { NULL, 1048586, "ub-country-name-alpha-length"},
   { "postal-code", 1342177283, "9"},
   { "PostalCode", 1610612754, NULL },
-  { "numeric-code", 1612709890, "NumericString"},
+  { "numeric-code", 1612709916, NULL },
   { "ub-postal-code-length", 524298, "1"},
-  { "printable-code", 538968066, "PrintableString"},
+  { "printable-code", 538968095, NULL },
   { "ub-postal-code-length", 524298, "1"},
   { "physical-delivery-office-name", 1342177283, "10"},
   { "PhysicalDeliveryOfficeName", 1073741826, "PDSParameter"},
@@ -747,9 +916,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "UnformattedPostalAddress", 1610612750, NULL },
   { "printable-address", 1814052875, NULL },
   { "ub-pds-physical-address-lines", 1074266122, "1"},
-  { NULL, 538968066, "PrintableString"},
+  { NULL, 538968095, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
-  { "teletex-string", 740311042, "TeletexString"},
+  { "teletex-string", 740311070, NULL },
   { "ub-unformatted-address-length", 524298, "1"},
   { "street-address", 1342177283, "17"},
   { "StreetAddress", 1073741826, "PDSParameter"},
@@ -762,17 +931,17 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "local-postal-attributes", 1342177283, "21"},
   { "LocalPostalAttributes", 1073741826, "PDSParameter"},
   { "PDSParameter", 1610612750, NULL },
-  { "printable-string", 1814052866, "PrintableString"},
+  { "printable-string", 1814052895, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
-  { "teletex-string", 740311042, "TeletexString"},
+  { "teletex-string", 740311070, NULL },
   { "ub-pds-parameter-length", 524298, "1"},
   { "extended-network-address", 1342177283, "22"},
   { "ExtendedNetworkAddress", 1610612754, NULL },
   { "e163-4-address", 1610612741, NULL },
-  { "number", 1612718082, "NumericString"},
+  { "number", 1612718108, NULL },
   { NULL, 1073743880, "0"},
   { "ub-e163-4-number-length", 524298, "1"},
-  { "sub-address", 538992642, "NumericString"},
+  { "sub-address", 538992668, NULL },
   { NULL, 1073743880, "1"},
   { "ub-e163-4-sub-address-length", 524298, "1"},
   { "psap-address", 536879106, "PresentationAddress"},
@@ -801,9 +970,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "ub-domain-defined-attributes", 1074266122, "1"},
   { NULL, 2, "TeletexDomainDefinedAttribute"},
   { "TeletexDomainDefinedAttribute", 1610612741, NULL },
-  { "type", 1612709890, "TeletexString"},
+  { "type", 1612709918, NULL },
   { "ub-domain-defined-attribute-type-length", 524298, "1"},
-  { "value", 538968066, "TeletexString"},
+  { "value", 538968094, NULL },
   { "ub-domain-defined-attribute-value-length", 524298, "1"},
   { "ub-name", 1342177283, "32768"},
   { "ub-common-name", 1342177283, "64"},
@@ -904,9 +1073,9 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073741825, "pkcs-9"},
   { NULL, 1, "7"},
   { "pkcs-9-challengePassword", 1610612754, NULL },
-  { "printableString", 1612709890, "PrintableString"},
+  { "printableString", 1612709919, NULL },
   { "pkcs-9-ub-challengePassword", 524298, "1"},
-  { "utf8String", 538968066, "UTF8String"},
+  { "utf8String", 538968098, NULL },
   { "pkcs-9-ub-challengePassword", 524298, "1"},
   { "pkcs-9-at-localKeyId", 1879048204, NULL },
   { NULL, 1073741825, "pkcs-9"},
@@ -915,7 +1084,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "pkcs-9-at-friendlyName", 1879048204, NULL },
   { NULL, 1073741825, "pkcs-9"},
   { NULL, 1, "20"},
-  { "pkcs-9-friendlyName", 1612709890, "BMPString"},
+  { "pkcs-9-friendlyName", 1612709921, NULL },
   { "255", 524298, "1"},
   { "pkcs-8-PrivateKeyInfo", 1610612741, NULL },
   { "version", 1073741826, "pkcs-8-Version"},
@@ -1070,7 +1239,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { NULL, 1073741825, "100"},
   { NULL, 1073741825, "1"},
   { NULL, 1, "25"},
-  { "domainComponent", 1073741826, "IA5String"},
+  { "domainComponent", 1073741853, NULL },
   { "id-at-userId", 1880096780, "AttributeType"},
   { NULL, 1073741825, "0"},
   { NULL, 1073741825, "9"},
@@ -1086,7 +1255,7 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "id-pda-dateOfBirth", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-pda"},
   { NULL, 1, "1"},
-  { "DateOfBirth", 1082130449, NULL },
+  { "DateOfBirth", 1073741861, NULL },
   { "id-pda-placeOfBirth", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-pda"},
   { NULL, 1, "2"},
@@ -1094,21 +1263,21 @@ const ASN1_ARRAY_TYPE pkix_asn1_tab[] = {
   { "id-pda-gender", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-pda"},
   { NULL, 1, "3"},
-  { "Gender", 1612709890, "PrintableString"},
+  { "Gender", 1612709919, NULL },
   { NULL, 1048586, "1"},
   { "id-pda-countryOfCitizenship", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-pda"},
   { NULL, 1, "4"},
-  { "CountryOfCitizenship", 1612709890, "PrintableString"},
+  { "CountryOfCitizenship", 1612709919, NULL },
   { NULL, 1048586, "2"},
   { "id-pda-countryOfResidence", 1880096780, "AttributeType"},
   { NULL, 1073741825, "id-pda"},
   { NULL, 1, "5"},
-  { "CountryOfResidence", 1612709890, "PrintableString"},
+  { "CountryOfResidence", 1612709919, NULL },
   { NULL, 1048586, "2"},
   { "PublicKeyAndChallenge", 1610612741, NULL },
   { "spki", 1073741826, "SubjectPublicKeyInfo"},
-  { "challenge", 2, "IA5String"},
+  { "challenge", 29, NULL },
   { "SignedPublicKeyAndChallenge", 1610612741, NULL },
   { "publicKeyAndChallenge", 1073741826, "PublicKeyAndChallenge"},
   { "signatureAlgorithm", 1073741826, "AlgorithmIdentifier"},
