@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
@@ -227,7 +225,7 @@ on_create_file_ready (GObject *source, GAsyncResult *res, gpointer user_data)
 		     _("A file already exists with this name."),
 		     _("Do you want to replace it with a new file?"));
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-		                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                        _("_Cancel"), GTK_RESPONSE_CANCEL,
 		                        _("_Replace"), GTK_RESPONSE_ACCEPT, NULL);
 
 		g_signal_connect (dialog, "response",
@@ -304,8 +302,8 @@ exporter_display_chooser (GcrCertificateExporter *self)
 
 	dialog = gtk_file_chooser_dialog_new (_("Export certificate"),
 	                     NULL, GTK_FILE_CHOOSER_ACTION_SAVE,
-	                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	                     GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+	                     _("_Cancel"), GTK_RESPONSE_CANCEL,
+	                     _("_Save"), GTK_RESPONSE_ACCEPT,
 	                     NULL);
 
 	self->pv->chooser_dialog = g_object_ref_sink(dialog);
@@ -342,7 +340,7 @@ exporter_display_chooser (GcrCertificateExporter *self)
 		g_cancellable_connect (self->pv->cancellable,
 		                       G_CALLBACK (on_cancel_chooser_dialog), self, NULL);
 
-	gtk_widget_show (GTK_WIDGET (self->pv->chooser_dialog));
+	gtk_dialog_run (GTK_DIALOG (self->pv->chooser_dialog));
 }
 
 /* -----------------------------------------------------------------------------
@@ -524,10 +522,10 @@ _gcr_certificate_exporter_export_async (GcrCertificateExporter *self,
 	if (cancellable)
 		self->pv->cancellable = g_object_ref (cancellable);
 
-	exporter_display_chooser (self);
-
 	/* Matching in export_finish */
 	g_object_ref (self);
+
+	exporter_display_chooser (self);
 }
 
 gboolean
